==> apache-calcite-1.36.0-src.tar.gz: apache-calcite-1.36.0-src/testkit/src/main/java/org/apache/calcite/test/schemata/hr/Department.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.test.schemata.hr;

import java.util.List;
import java.util.Objects;

/**
 * Department model.
 */
public class Department {
  public final int deptno;
  public final String name;

  @org.apache.calcite.adapter.java.Array(component = Employee.class)
  public final List<Employee> employees;
  public final Location location;

  public Department(int deptno, String name, List<Employee> employees,
      Location location) {
    this.deptno = deptno;
    this.name = name;
    this.employees = employees;
    this.location = location;
  }

  @Override public String toString() {
    return "Department [deptno: " + deptno + ", name: " + name
        + ", employees: " + employees + ", location: " + location + "]";
  }

  @Override public boolean equals(Object obj) {
    return obj == this
        || obj instanceof Department
        && deptno == ((Department) obj).deptno;
  }

  @Override public int hashCode() {
    return Objects.hash(deptno);
  }
}

==> apache-calcite-1.40.0-src.tar.gz: apache-calcite-1.40.0-src/testkit/src/main/java/org/apache/calcite/test/schemata/hr/Department.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.test.schemata.hr;

import org.checkerframework.checker.nullness.qual.Nullable;

import java.util.List;
import java.util.Objects;

/**
 * Department model.
 */
public class Department {
  public final int deptno;
  public final String name;

  @org.apache.calcite.adapter.java.Array(component = Employee.class)
  public final List<Employee> employees;
  public final @Nullable Location location;

  public Department(int deptno, String name, List<Employee> employees,
      @Nullable Location location) {
    this.deptno = deptno;
    this.name = name;
    this.employees = employees;
    this.location = location;
  }

  @Override public String toString() {
    return "Department [deptno: " + deptno + ", name: " + name
        + ", employees: " + employees + ", location: " + location + "]";
  }

  @Override public boolean equals(Object obj) {
    return obj == this
        || obj instanceof Department
        && deptno == ((Department) obj).deptno;
  }

  @Override public int hashCode() {
    return Objects.hash(deptno);
  }
}
